@@ -17,7 +17,10 @@ test_that("mlflow_client_list_experiments() works properly", {
   experiments_list <- mlflow_client_list_experiments(client = client)
   expect_setequal(experiments_list$experiment_id, c("0", "1", "2"))
   expect_setequal(experiments_list$name, c("Default", "foo1", "foo2"))
-  expect_setequal(experiments_list$artifact_location, c("mlruns/0", "art_loc1", "art_loc2"))
+  default_artifact_loc <- paste(getwd(), "/mlruns/0", sep = "")
+  expect_setequal(experiments_list$artifact_location, c(default_artifact_loc,
+                                                        "art_loc1",
+                                                        "art_loc2"))
 })
 
 test_that("mlflow_client_get_experiment() works properly", {
@@ -30,6 +33,19 @@ test_that("mlflow_client_get_experiment() works properly", {
   expect_identical(experiment$experiment$artifact_location, "art_loc1")
 })
 
+
+test_that("mlflow_client_get_experiment_by_name() works properly", {
+  mlflow_clear_test_dir("mlruns")
+  client <- mlflow_client()
+  experiment <- mlflow_client_get_experiment_by_name(client = client, "exp")
+  expect_null(experiment)
+  experiment_id <- mlflow_client_create_experiment(client = client, "exp", "art")
+  experiment <- mlflow_client_get_experiment_by_name(client = client, "exp")
+  expect_identical(experiment_id, experiment$experiment_id)
+  expect_identical(experiment$name, "exp")
+  expect_identical(experiment$artifact_location, "art")
+})
+
 test_that("mlflow_client_create_run()/mlflow_client_get_run() work properly", {
   mlflow_clear_test_dir("mlruns")
   client <- mlflow_client()
@@ -78,3 +94,16 @@ test_that("mlflow_set_tag() should return NULL invisibly", {
   value <- mlflow_set_tag("foo", "bar")
   expect_null(value)
 })
+
+test_that("infer experiment id works properly", {
+  mlflow_clear_test_dir("mlruns")
+  experiment_id <- mlflow_create_experiment("test")
+  Sys.setenv(MLFLOW_EXPERIMENT_NAME = "test")
+  expect_true(experiment_id == mlflow_infer_experiment_id())
+  Sys.unsetenv("MLFLOW_EXPERIMENT_NAME")
+  Sys.setenv(MLFLOW_EXPERIMENT_ID = experiment_id)
+  expect_true(experiment_id == mlflow_infer_experiment_id())
+  Sys.unsetenv("MLFLOW_EXPERIMENT_ID")
+  mlflow_set_experiment("test")
+  expect_true(experiment_id == mlflow_infer_experiment_id())
+})
